==> binford2k-azure_delete_empty_loadbalancers-0.0.4.tar.gz: binford2k-azure_delete_empty_loadbalancers-0.0.4/README.md <==
This workflow finds empty Azure load balancers by locating load balancers that have no backend configurations. It then terminates these load balancers.

## Prerequisites

Before you run this workflow, you will need the following:  
- An Azure Subscription  
- An Azure Service Principal with permissions to manage load balancers.  
- One or more Azure Load Balancers with zero back end configurations.  

## Run the workflow  

[Use thiw workflow](https://app.relay.sh/create-workflow?workflowName=azure-delete-empty-loadbalancers&initialContentURL=https%3A%2F%2Fraw.githubusercontent.com%2Fpuppetlabs%2Frelay-workflows%2Fmaster%2Fazure-delete-empty-loadbalancers%2Fazure-delete-empty-loadbalancers.yaml)

Follow these steps to run the workflow:  
1. Add your Azure credentials as a Connection:  
   - Click **Setup**  
   - Find the Connection named `my-azure-account` and click Edit(✎). Use the following values:  
      - **KEY**: `CLIENT ID`  
      - **VALUE**: Enter your Azure Client ID associated with the service principal  
      - **KEY**: `SECRET`  
      - **VALUE**: Enter your Azure Secret associated with the service principal  
      - **KEY**: `TENANT ID`  
      - **VALUE**: Enter your Azure Tenant ID associated with the service principal    
      - **KEY**: `SUBSCRIPTION ID`  
      - **VALUE**: Enter your Azure Subscription ID   
   - Click **Save**  

2. Click **Run workflow** and wait for the workflow run page to appear.  
3. Supply following parameters to the modal:  
   - **KEY**: `dryRun`  
   - **VALUE**: True if you don't want to perform actual WRITE operations  

4. **Warning:** If you run the workflow with the `dryRun` parameter set to
   `false`, resources will be immediately terminated.  

## Run the workflow on a schedule  

Follow these steps to run this workflow on a schedule:  
-  Un-comment out the Trigger block in the workflow file:  

> TIP: If you're using the Relay code editor, highlight the `triggers` section and type `⌘ + /` (Mac) or `Ctrl + /` (Windows) to uncomment.  

```yaml
# triggers:
# - name: schedule
#   source:
#     type: schedule
#     schedule: '0 * * * *'
#   binding:
#     parameters:
#       dryRun: true
```

-  Configure the `schedule` trigger:  
   - Supply the run interval in [cron format](https://crontab.guru/).  
-  Configure the following parameter bindings:  
   - Specify whether `dryRun` should be set to `true` or `false`.  
-  Click **Save changes**

==> binford2k-azure_delete_empty_loadbalancers-0.0.6.tar.gz: binford2k-azure_delete_empty_loadbalancers-0.0.6/README.md <==
This workflow finds empty Azure load balancers by locating load balancers that have no backend configurations. It then terminates these load balancers.

## Prerequisites

Before you run this workflow, you will need the following:
- An Azure Subscription
- An Azure Service Principal with permissions to manage load balancers.
- One or more Azure Load Balancers with zero back end configurations.

## Run the workflow

[![Try this workflow](https://i.imgur.com/n5qr3FC.png)](https://app.relay.sh/create-workflow?workflowName=azure-delete-empty-loadbalancers&initialContentURL=https%3A%2F%2Fraw.githubusercontent.com%2Fpuppetlabs%2Frelay-workflows%2Fmaster%2Fazure-delete-empty-loadbalancers%2Fazure-delete-empty-loadbalancers.yaml)

Follow these steps to run the workflow:
1. Add your Azure credentials as a Connection:
   - Click **Setup**
   - Find the Connection named `my-azure-account` and click Edit(✎). Use the following values:
      - **KEY**: `CLIENT ID`
      - **VALUE**: Enter your Azure Client ID associated with the service principal
      - **KEY**: `SECRET`
      - **VALUE**: Enter your Azure Secret associated with the service principal
      - **KEY**: `TENANT ID`
      - **VALUE**: Enter your Azure Tenant ID associated with the service principal
      - **KEY**: `SUBSCRIPTION ID`
      - **VALUE**: Enter your Azure Subscription ID
   - Click **Save**

2. Click **Run workflow** and wait for the workflow run page to appear.
3. Supply following parameters to the modal:
   - **KEY**: `dryRun`
   - **VALUE**: True if you don't want to perform actual WRITE operations

4. **Warning:** If you run the workflow with the `dryRun` parameter set to
   `false`, resources will be immediately terminated.

## Run the workflow on a schedule

Follow these steps to run this workflow on a schedule:
-  Un-comment out the Trigger block in the workflow file:

> TIP: If you're using the Relay code editor, highlight the `triggers` section and type `⌘ + /` (Mac) or `Ctrl + /` (Windows) to uncomment.

```yaml
# triggers:
# - name: schedule
#   source:
#     type: schedule
#     schedule: '0 * * * *'
#   binding:
#     parameters:
#       dryRun: true
```

-  Configure the `schedule` trigger:
   - Supply the run interval in [cron format](https://crontab.guru/).
-  Configure the following parameter bindings:
   - Specify whether `dryRun` should be set to `true` or `false`.
-  Click **Save changes**
